#
# spec file for package duktape
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 207
Name:           duktape
VCS: https://src.suse.de/SLFO-pool/duktape#f5f1b9f9d4aed922ab3a7c0ae21e3a44fa9b65f4f4b68d71e31ec61db2e4cd73
Version:        2.7.0
Release:        160000.1.10
Summary:        Embeddable Javascript engine
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://duktape.org/
Source0:        https://duktape.org/%{name}-%{version}.tar.xz
Patch0:         duktape-link-m.patch
BuildRequires:  gcc
BuildRequires:  pkgconfig

%description
Duktape is an embeddable Javascript engine, with a focus on portability and
compact footprint.

%package -n     lib%{name}%{sover}
Summary:        The core library for %{name}
Group:          System/Libraries

%description -n lib%{name}%{sover}
Embeddable Javascript engine.

This package contains the shared library.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}

%description    devel
Embeddable Javascript engine.

This package contains header files and libraries needed to develop
application that use %{name}.

%prep
%autosetup -p1

%build
%make_build -f Makefile.sharedlibrary INSTALL_PREFIX=%{_prefix} LIBDIR=/%{_lib}

%install
%make_install -f Makefile.sharedlibrary INSTALL_PREFIX=%{_prefix} LIBDIR=/%{_lib}

%ldconfig_scriptlets -n lib%{name}%{sover}

%files -n lib%{name}%{sover}
%doc AUTHORS.rst
%license LICENSE.txt
%{_libdir}/libduktape.so.*
%{_libdir}/libduktaped.so.*

%files devel
%{_includedir}/duk_config.h
%{_includedir}/duktape.h
%{_libdir}/libduktape.so
%{_libdir}/libduktaped.so
%{_libdir}/pkgconfig/duktape.pc

%changelog
* Wed Apr 12 2023 bjorn.lie@gmail.com
- Update to version 2.7.0:
  * Fix memory unsafe behavior when valstack size limit hit in
    call setup
  * Fix a realloc() memory leak triggered when (1) previous
    allocation exists, (2) new realloc size is 0, (3) GC is
    triggered before first realloc() attempt
  * Fix void pointer arithmetic in duk_alloc_pool.c, caused
    problems with MSVC
  * Fix broken bytecode dump on big endian architectures
  * Fix DUK_USE_GET_RANDOM_DOUBLE() argument handling
  * Use yaml.safe_load() instead of yaml.load() in Py2 tooling
  * Dist makefile and pkg-config improvements
  * Fix Makefile.jsoncbor build
  * Reformat source with clang-format-12
- Bump sover define following upstream changes.
- Rebase duktape-link-m.patch with quilt.
- Drop pc.in file, no longer needed.
- Pass the needed prefixes etc to make_build and make_install.
- Use ldconfig_scriptlets macro.
* Mon Nov 28 2022 meissner@suse.com
- duktape-link-m.patch: link against libm for sin() and related functions,
  in case the compiler with -Os creates external references. bsc#1205805
* Fri Oct 30 2020 stefan.bruens@rwth-aachen.de
- Update to 2.6.0:
  * Various fixes and portability improvements.
* Tue Jul 28 2020 mrey@suse.com
- Update to 2.5.0:
  * CBOR support, minor fixes and improvements
- spec file changes
  * change http to https in URLs
  * use RPM macros
* Mon Jul 29 2019 avvissu@yandex.by
- Update to 2.4.0:
  * Minor fixes and improvements
* Thu Oct 18 2018 sean@suspend.net
- Update to 2.3.0:
  * ES2015 improvements
* Thu Apr 26 2018 avvissu@yandex.by
- Update to 2.2.1:
  * maintenance release
* Thu Oct  5 2017 avvissu@yandex.by
- Update to 2.2.0:
  * call handling, API improvements, performance
* Sat Jul 29 2017 avvissu@yandex.by
- Update to 2.1.1:
  * maintenance release
* Thu Jun  1 2017 jengelh@inai.de
- Correct RPM group.
* Tue May 30 2017 avvissu@yandex.by
- Initial package
